( cd usr/man/mann ; rm -rf ckfree.n.gz )
( cd usr/man/mann ; ln -sf /usr/man/mann/ckalloc.n.gz ckfree.n.gz )
( cd usr/man/mann ; rm -rf Tcl_DisplayMemory.n.gz )
( cd usr/man/mann ; ln -sf /usr/man/mann/ckalloc.n.gz Tcl_DisplayMemory.n.gz )
( cd usr/man/mann ; rm -rf Tcl_InitMemory.n.gz )
( cd usr/man/mann ; ln -sf /usr/man/mann/ckalloc.n.gz Tcl_InitMemory.n.gz )
( cd usr/man/mann ; rm -rf Tcl_ValidateAllMemory.n.gz )
( cd usr/man/mann ; ln -sf /usr/man/mann/ckalloc.n.gz Tcl_ValidateAllMemory.n.gz )
( cd usr/man/mann ; rm -rf memory.n.gz )
( cd usr/man/mann ; ln -sf /usr/man/mann/ckalloc.n.gz memory.n.gz )
( cd usr/man/man3 ; rm -rf Tcl_HandleFree.3 )
( cd usr/man/man3 ; ln -sf /usr/man/man3/Tcl_HandleAlloc.3 Tcl_HandleFree.3 )
( cd usr/man/man3 ; rm -rf Tcl_HandleTblInit.3 )
( cd usr/man/man3 ; ln -sf /usr/man/man3/Tcl_HandleAlloc.3 Tcl_HandleTblInit.3 )
( cd usr/man/man3 ; rm -rf Tcl_HandleTblRelease.3 )
( cd usr/man/man3 ; ln -sf /usr/man/man3/Tcl_HandleAlloc.3 Tcl_HandleTblRelease.3 )
( cd usr/man/man3 ; rm -rf Tcl_HandleTblUseCount.3 )
( cd usr/man/man3 ; ln -sf /usr/man/man3/Tcl_HandleAlloc.3 Tcl_HandleTblUseCount.3 )
( cd usr/man/man3 ; rm -rf Tcl_HandleWalk.3 )
( cd usr/man/man3 ; ln -sf /usr/man/man3/Tcl_HandleAlloc.3 Tcl_HandleWalk.3 )
( cd usr/man/man3 ; rm -rf Tcl_HandleXlate.3 )
( cd usr/man/man3 ; ln -sf /usr/man/man3/Tcl_HandleAlloc.3 Tcl_HandleXlate.3 )
( cd usr/man/man3 ; rm -rf TclX_KeyedListGet.3 )
( cd usr/man/man3 ; ln -sf /usr/man/man3/TclX_NewKeyedListObj.3 TclX_KeyedListGet.3 )
( cd usr/man/man3 ; rm -rf TclX_KeyedListSet.3 )
( cd usr/man/man3 ; ln -sf /usr/man/man3/TclX_NewKeyedListObj.3 TclX_KeyedListSet.3 )
( cd usr/man/man3 ; rm -rf TclX_KeyedListDelete.3 )
( cd usr/man/man3 ; ln -sf /usr/man/man3/TclX_NewKeyedListObj.3 TclX_KeyedListDelete.3 )
( cd usr/man/man3 ; rm -rf TclX_KeyedListGetKeys.3 )
( cd usr/man/man3 ; ln -sf /usr/man/man3/TclX_NewKeyedListObj.3 TclX_KeyedListGetKeys.3 )
( cd usr/man/man3 ; rm -rf Tclxcmd_Init.3 )
( cd usr/man/man3 ; ln -sf /usr/man/man3/Tclx_Init.3 Tclxcmd_Init.3 )
( cd usr/man/man3 ; rm -rf TclX_Main.3 )
( cd usr/man/man3 ; ln -sf /usr/man/man3/Tclx_Init.3 TclX_Main.3 )
( cd usr/man/man3 ; rm -rf Tkx_Init.3 )
( cd usr/man/man3 ; ln -sf /usr/man/man3/Tclx_Init.3 Tkx_Init.3 )
( cd usr/man/man3 ; rm -rf TkX_Main.3 )
( cd usr/man/man3 ; ln -sf /usr/man/man3/Tclx_Init.3 TkX_Main.3 )
