#
# tkxConfig.sh - This file is generated by the TclX configure script to
# assist in linking with TclX Tk support (libtkx.a).  It is a shell scripted
# designed to be sourced by configure scripts.  The system libraries defined
# in here need to be used in addition to those defined in tclConfig.sh,
# tclxConfig.sh and tkConfig.sh.  See tclExtend.h for a full expanation of the
# version numbers.  No values are currently filled in for TKX_LIBS.  Its just
# kept for future expansibility.
#
# System: Linux-2.4.32-gl070220
# Date:   Tue Feb 27 18:47:57 EST 2007
#

#
# Version number for TkX (see tclExtend.h for details).
#
TKX_FULL_VERSION='8.3.0'

#
# Defines for cpp.
#
TKX_DEFS=' -DSTDC_HEADERS=1 -Dclock_t=long -DRETSIGTYPE=void '

#
# Additional libraries added by TclX.
#
TKX_LIBS=''

#
# String to pass to linker to pick up the TkX library from its
# build directory.
#
TKX_BUILD_LIB_SPEC='-L/tmp/tclx8.3.5/tk/unix -ltkx8.3'

#
# String to pass to linker to pick up the TclX library from its
# installed directory.
#
TKX_LIB_SPEC='-L -ltkx8.3'


