#
# tclxConfig.sh - This file is generated by the TclX configure script to
# assist in linking with TclX (libtclx.a).  It is a shell scripted designed to
# be sourced by configure scripts.  The system libraries defined in here
# need to be used in addition to those defined in tclConfig.sh.  See
# tclExtend.h for a full expanation of the version numbers.
#
# System: Linux-2.4.32-gl070220
# Date:   Tue Feb 27 18:47:57 EST 2007
#

#
# Version numbers for TclX (see tclExtend.h for details).
#
TCLX_FULL_VERSION='8.3.0'
TCLX_VERSION='8.3'

#
# Defines for cpp.
#
TCLX_DEFS=' -DSTDC_HEADERS=1 -Dclock_t=long -DRETSIGTYPE=void '

#
# Additional libraries added by TclX.
#
TCLX_LIBS=''

#
# String to pass to linker to pick up the TclX library from its
# build directory.
#
TCLX_BUILD_LIB_SPEC='-L/tmp/tclx8.3.5/tcl/unix -ltclx8.3'

#
# String to pass to linker to pick up the TclX library from its
# installed directory.
#
TCLX_LIB_SPEC='-L -ltclx8.3'

#
# Search flags that specify how to find the TclX shared libraries at run time
# on some systems.
#
TCLX_LD_SEARCH_FLAGS='@TCLX_LD_SEARCH_FLAGS@'


